@@ -41,7 +41,7 @@ class StableDiffusionControlNetScribbleGenerator:
 
         return self.pipe
 
-    def controlnet_scribble(image_path: str):
+    def controlnet_scribble(self, image_path: str):
         hed = HEDdetector.from_pretrained("lllyasviel/ControlNet")
 
         image = Image.open(image_path)
@@ -97,13 +97,13 @@ class StableDiffusionControlNetScribbleGenerator:
                     )
                     controlnet_scribble_prompt = gr.Textbox(
                         lines=1,
-                        label="Prompt",
+                        show_label=False,
                         placeholder="Prompt",
                     )
 
                     controlnet_scribble_negative_prompt = gr.Textbox(
                         lines=1,
-                        label="Negative Prompt",
+                        show_label=False,
                         placeholder="Negative Prompt",
                     )
 
